<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:src="http://purl.oclc.org/dsdl/9573-11amd1/ns/structure/1.0"
  xmlns:fo="http://www.w3.org/1999/XSL/Format">
  <!-- XSL-FO for TR9573-11/Amd.1 -->
  <!-- version.0.5 -->
<!--  
README:
This stylesheet aims to format ISO standards written by XML towards TR 9573-11/Amd.1. This stylesheet is edited within creating sample layout for ISO7919-2. Therefore, this stylesheet may not be available for all ISO standards.

The result of rendering of FO is comfirming using Apache fop ver.0.20.5rc. If other rendering tools are used, the result may differ from the expected one.

On the technical point of view; 
- ISO number information of header/footer is obtained by the front page, 
- each cell could designate the availability of border lines,
- table of contents is automatically created by passing a parameter of name toc with value "yes" to this stylesheet,
- passing a parameter of name tpage with value "no" to this stylesheet prohibits automatically generation of the title page,
- this stylesheet is corresponded to both English and French by designating in attribute and so on.
-->
  <xsl:import href="attributeset.xsl"/>
  <xsl:import href="layoutmaster.xsl"/>
  <xsl:import href="stdex_fo_front.xsl"/>
  <xsl:import href="stdex_fo_toc.xsl"/>
  <xsl:import href="stdex_fo_back.xsl"/>
  <xsl:import href="language.xsl"/>
  <xsl:import href="library.xsl"/>
  <xsl:output method="xml" indent="yes"/>

  <xsl:param name="toc" select="'yes'"/>
  <xsl:param name="tpage" select="'yes'"/>
  
  <xsl:variable name="quote" select="'10mm'"/>
  <xsl:variable name="halfquote" select="'5mm'"/>
  <xsl:variable name="widequote" select="'15mm'"/>
  
  <xsl:template match="/">
    <fo:root>
      <xsl:choose>
        <xsl:when test="$lng='E'">
          <xsl:attribute name="language">en</xsl:attribute>
        </xsl:when>
        <xsl:when test="$lng='F'">
          <xsl:attribute name="language">fr</xsl:attribute>
        </xsl:when>
      </xsl:choose>
      <xsl:call-template name="layoutmaster"/>
      <xsl:apply-templates/>
    </fo:root>
  </xsl:template>

  <xsl:template match="src:document">
    <fo:page-sequence master-reference="prev" initial-page-number="1" format="i">
      <xsl:call-template name="headfoot"/>
      <fo:flow flow-name="xsl-region-body" xsl:use-attribute-sets="default">
        <xsl:if test="$tpage='yes'">
          <xsl:call-template name="frontm"/>
        </xsl:if>
        <xsl:if test="$toc='yes'">
          <xsl:call-template name="toc"/>
        </xsl:if>
        <xsl:apply-templates select="src:foreword"/>
        <xsl:apply-templates select="src:introduction"/>
      </fo:flow>
    </fo:page-sequence>
    <fo:page-sequence master-reference="stdex" initial-page-number="1">
      <xsl:call-template name="headfoot"/>
      <fo:flow flow-name="xsl-region-body" xsl:use-attribute-sets="default">
        <fo:block break-before="page">
          <xsl:call-template name="btop"/>
          <xsl:apply-templates select="src:scope"/>
          <xsl:apply-templates select="src:warning"/>
          <xsl:apply-templates select="src:conf"/>
          <xsl:apply-templates select="src:normative-references"/>
          <xsl:apply-templates select="src:terms-and-definition"/>
          <xsl:apply-templates select="src:clause"/>
          <xsl:apply-templates select="src:annex"/>
          <xsl:apply-templates select="src:bibliography"/>
          <xsl:apply-templates select="src:index"/>
        </fo:block>
      </fo:flow>
    </fo:page-sequence>
    <fo:page-sequence master-reference="back" initial-page-number="1">
      <xsl:call-template name="headfoot"/>
      <fo:flow flow-name="xsl-region-body" xsl:use-attribute-sets="default">
        <fo:block break-before="page"/>
        <xsl:call-template name="backm"/>
      </fo:flow>
    </fo:page-sequence>
  </xsl:template>

  <xsl:template match="src:head"/>

  <xsl:template match="src:foreword">
    <fo:block break-before="page" padding-top="51pt">
      <fo:block xsl:use-attribute-sets="h1">
        <xsl:call-template name="anchor-text">
          <xsl:with-param name="anc" select="'foreword'"/>
          <xsl:with-param name="text">
            <xsl:call-template name="forewordstr">
              <xsl:with-param name="lang" select="$lng"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </fo:block>
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>

  <xsl:template match="src:part-list">
    <fo:list-block>
      <xsl:apply-templates />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="src:part">
    <fo:list-item xsl:use-attribute-sets="item">
      <fo:list-item-label>
        <fo:block><xsl:text>&#8212;</xsl:text></fo:block>
      </fo:list-item-label>
      <fo:list-item-body start-indent="{$halfquote}">
        <fo:block>
          <xsl:text>&#160;Part&#160;</xsl:text>
          <xsl:apply-templates select="src:number" />
          <xsl:text>:&#160;</xsl:text>
          <xsl:apply-templates select="src:title" />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="src:part/src:number">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:part/src:title">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:introduction">
    <fo:block break-before="page" padding-top="51pt">
      <fo:block xsl:use-attribute-sets="h1">
        <xsl:call-template name="anchor-text">
          <xsl:with-param name="anc" select="'introduction'"/>
          <xsl:with-param name="text">
            <xsl:call-template name="introductionstr">
              <xsl:with-param name="lang" select="$lng"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </fo:block>
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>
  
  <xsl:template name="anchor-text">
    <xsl:param name="anc" />
    <xsl:param name="text" />
    <fo:inline id="{$anc}">
      <xsl:copy-of select="$text" />
    </fo:inline>
  </xsl:template>
  
  <xsl:template match="src:warning">
    <!-- contents: { attlist.warning, p* } -->
    <xsl:text>WARNING-</xsl:text>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:scope">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:choose>
        <xsl:when test="$lng='E'">
          <xsl:text>Scope</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Domaine d'application</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h2">
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
      </xsl:call-template>
    </fo:block>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:conf">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:choose>
        <xsl:when test="$lng='E'">
          <xsl:text>Conformance</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Conformance</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h2">
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
      </xsl:call-template>
    </fo:block>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:normative-references">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:choose>
        <xsl:when test="$lng='E'">
          <xsl:text>Normative references</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>R&#233;f&#233;rences normatives</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h2">
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
      </xsl:call-template>
    </fo:block>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:referenced-document">
    <fo:block xsl:use-attribute-sets="p">
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:abbrev">
    <xsl:apply-templates/>
    <xsl:text>, </xsl:text>
  </xsl:template>    
  
  <xsl:template match="src:referenced-document/src:title">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:terms-and-definitions">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:choose>
        <xsl:when test="$lng='E'">
          <xsl:text>Terms and definitions</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>Termes, d&#233;finitions et symboles</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h1">
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
      </xsl:call-template>
    </fo:block>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:term-and-definition">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:term-and-definition/src:term">
    <fo:block>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:term-and-definition/src:definition">
    <fo:block>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:clause">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:clause/src:title">
    <xsl:variable name="level" select="count(ancestor::src:clause|ancestor::src:annex)" />
    <xsl:variable name="nth">
      <xsl:choose>
        <xsl:when test="ancestor::src:annex">
          <xsl:number level="multiple" count="src:annex|src:annex//src:clause" format="A.1" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" format="1.1" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h2">
      <xsl:attribute name="font-size">
        <xsl:choose>
          <xsl:when test="$level='0'">
            <xsl:text>14pt</xsl:text>
          </xsl:when>
          <xsl:when test="$level='1'">
            <xsl:text>12pt</xsl:text>
          </xsl:when>
          <xsl:when test="$level='2'">
            <xsl:text>11pt</xsl:text>
          </xsl:when>
          <xsl:when test="$level='3'">
            <xsl:text>10pt</xsl:text>
          </xsl:when>
          <xsl:when test="$level='4'">
            <xsl:text>9pt</xsl:text>
          </xsl:when>
          <xsl:when test="$level='5'">
            <xsl:text>9pt</xsl:text>
          </xsl:when>
        </xsl:choose>
      </xsl:attribute>
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text">
          <xsl:value-of select="$nth" />
          <xsl:text> </xsl:text>
          <xsl:apply-templates />
        </xsl:with-param>
      </xsl:call-template>
    </fo:block>
  </xsl:template>

  <xsl:template match="src:annex">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:annex/src:title">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:annex" format="A" />
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="h1" text-align="center" break-before="page">
      <fo:block>
        <xsl:text>Annex </xsl:text>
        <xsl:value-of select="$nth" />
      </fo:block>
      <fo:block>
        <xsl:choose>
          <xsl:when test="../@normative = 'true'">
            <xsl:text>(normative)</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>(informative)</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </fo:block>
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc" select="$nth" />
        <xsl:with-param name="text">
          <xsl:apply-templates />
        </xsl:with-param>
      </xsl:call-template>
    </fo:block>
  </xsl:template>

  <xsl:template match="src:bibliography">
    <fo:block break-before="page">
      <fo:block xsl:use-attribute-sets="h1" text-align="center">
        <xsl:call-template name="anchor-text">
          <xsl:with-param name="anc" select="'bibliography'"/>
          <xsl:with-param name="text">
            <xsl:call-template name="bibliographystr">
              <xsl:with-param name="lang" select="$lng"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </fo:block>
      <fo:list-block>
        <xsl:apply-templates/>
      </fo:list-block>
      <fo:inline id="biblioend"/>
    </fo:block>
  </xsl:template>
  
  <xsl:template match="src:bibliography/src:referenced-document">
    <fo:list-item xsl:use-attribute-sets="item">
      <fo:list-item-label>
        <fo:block>
          <xsl:number format="[1]"/>
        </fo:block>
      </fo:list-item-label>
      <fo:list-item-body start-indent="{$halfquote}">
        <fo:block>
          <xsl:apply-templates />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="src:index">
    <fo:block xsl:use-attribute-sets="h1" break-before="page">
      <xsl:call-template name="anchor-text">
        <xsl:with-param name="anc">index</xsl:with-param>
        <xsl:with-param name="text">Index</xsl:with-param>
      </xsl:call-template>
    </fo:block>
    <xsl:apply-templates />
  </xsl:template>
  
  <xsl:template match="src:p">
    <xsl:choose>
      <xsl:when test="(parent::src:note or parent::src:li) and not(preceding-sibling::src:p)">
        <fo:block>
          <xsl:apply-templates/>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <fo:block xsl:use-attribute-sets="p">
          <xsl:apply-templates/>
        </fo:block>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="src:ol">
    <fo:list-block>
      <xsl:apply-templates />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="src:ol/src:li">
    <xsl:variable name="l" select="count(ancestor::src:ul)+count(ancestor::src:ol)+count(ancestor::src:notation-list)"/>
    <xsl:variable name="level" select="count(ancestor::src:ol) mod 3" />
    <xsl:variable name="format">
      <xsl:choose>
        <xsl:when test="$level=1">
          <xsl:text>a)</xsl:text>
        </xsl:when>
        <xsl:when test="$level=2">
          <xsl:text>1)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>i)</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:list-item xsl:use-attribute-sets="item">
      <fo:list-item-label>
        <fo:block>
          <xsl:number format="{$format}" />
        </fo:block>
      </fo:list-item-label>
      <fo:list-item-body>
        <fo:block>
          <xsl:attribute name="start-indent">
            <xsl:value-of select="5 * $l"/><xsl:text>mm</xsl:text>
          </xsl:attribute>
          <xsl:apply-templates />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="src:ul">
    <fo:list-block>
      <xsl:apply-templates />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="src:ul/src:li">
    <xsl:variable name="l" select="count(ancestor::src:ul)+count(ancestor::src:ol)+count(ancestor::src:notation-list)"/>
    <xsl:variable name="level" select="count(ancestor::src:ul)" />
    <fo:list-item xsl:use-attribute-sets="item">
      <xsl:choose>
        <xsl:when test="$level=1">
          <fo:list-item-label>
            <fo:block>
              <xsl:text>&#8212;</xsl:text>
            </fo:block>
          </fo:list-item-label>
        </xsl:when>
        <xsl:otherwise>
          <fo:list-item-label>
            <fo:block>
              <xsl:text>-</xsl:text>
            </fo:block>
          </fo:list-item-label>
        </xsl:otherwise>
      </xsl:choose>
      <fo:list-item-body>
        <fo:block>
          <xsl:attribute name="start-indent">
            <xsl:value-of select="5 * $l"/><xsl:text>mm</xsl:text>
          </xsl:attribute>
          <xsl:apply-templates />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="src:warn">
    <fo:block xsl:use-attribute-sets="p" font-weight="bold">
      <xsl:call-template name="wrnstr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
      <xsl:text>&#8212; </xsl:text>
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>

  <xsl:template name="btop">
    <fo:block xsl:use-attribute-sets="btop">
      <xsl:apply-templates select="/src:document/src:head/src:title[@langcode=$lng]" mode="frontm"/>
    </fo:block>
  </xsl:template>

  <xsl:template match="src:notation-list">
    <fo:list-block>
      <xsl:apply-templates />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="src:notation-item">
    <fo:list-item xsl:use-attribute-sets="item">
      <xsl:apply-templates />
    </fo:list-item>
  </xsl:template>

  <xsl:template match="src:notation">
    <fo:list-item-label>
      <fo:block>
        <xsl:apply-templates/>
      </fo:block>
    </fo:list-item-label>
  </xsl:template>

  <xsl:template match="src:notation-definition">
    <xsl:variable name="l" select="count(ancestor::src:ul)+count(ancestor::src:ol)+count(ancestor::src:notation-list)"/>
    <fo:list-item-body>
      <fo:block>
        <xsl:attribute name="start-indent">
          <xsl:value-of select="5 * $l"/><xsl:text>mm</xsl:text>
        </xsl:attribute>
        <xsl:apply-templates />
      </fo:block>
    </fo:list-item-body>
  </xsl:template>

  <xsl:template match="src:example">
    <xsl:variable name="text">
      <xsl:call-template name="examplestr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
    </xsl:variable>
    <fo:block xsl:use-attribute-sets="p">
      <xsl:value-of select="$text"/>
      <xsl:text> </xsl:text>
      <xsl:if test="count(../src:example) &gt; 1">
        <xsl:number level="single" count="src:example" format="1 " />
      </xsl:if>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:note">
    <fo:block xsl:use-attribute-sets="p">
      <xsl:text>NOTE&#160;&#160;</xsl:text>
      <xsl:if test="count(../src:note) &gt; 1">
        <xsl:number level="single" count="src:note" format="1 " />
      </xsl:if>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:code">
    <fo:inline font-family="Courier">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:b">
    <fo:inline font-weight="bold">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:i">
    <fo:inline font-style="italic">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:u">
    <fo:inline text-decoration="underline">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:sup">
    <fo:inline font-size="60%" vertical-align="super">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:sub">
    <fo:inline font-size="60%" vertical-align="sub">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="src:var">
    <fo:inline font-family="Times" font-weight="bold">
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>
  
  <xsl:template match="src:This | src:this">
    <xsl:choose>
      <xsl:when test="/src:document/src:head/src:part-number">
        <xsl:choose>
          <xsl:when test="$lng='E'">
            <xsl:value-of select="local-name()" />
            <xsl:text> part of </xsl:text>
          </xsl:when>
        </xsl:choose>
        <xsl:value-of select="/src:document/src:head/src:organization" />
        <xsl:text> </xsl:text>
        <xsl:value-of select="/src:document/src:head/src:document-number" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="$lng='E'">
            <xsl:value-of select="local-name()" />
            <xsl:value-of select="/src:document/src:head/src:document-type" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
              <xsl:when test="local-name()='This'">
                <xsl:text>La</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>la</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:text> pr&#233;sente </xsl:text>
            <xsl:choose>
              <xsl:when test="/src:document/src:head/src:document-type='International Standard'">
                <xsl:text>Norme internationale</xsl:text>
              </xsl:when>
            </xsl:choose>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="src:Xref | src:xref">
    <xsl:variable name="to" select="@to" />
    <xsl:for-each select="//src:*[@id=$to]">
      <xsl:call-template name="xref-one" />
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="xref-one">
    <xsl:choose>
      <xsl:when test="self::src:footnote">
        <fo:inline font-size="60%" vertical-align="super">
          <xsl:number level="any" count="src:footnote" />
          <xsl:text>)</xsl:text>
        </fo:inline>
      </xsl:when>
      <xsl:when test="self::src:figure">
        <xsl:choose>
          <xsl:when test="ancestor::src:annex">
            <xsl:number level="multiple" count="src:annex|src:figure" format="A.1 " />
          </xsl:when>
          <xsl:otherwise>
            <xsl:number level="any" count="src:figure" />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="self::src:table">
        <xsl:choose>
          <xsl:when test="ancestor::src:annex">
            <xsl:number level="multiple" count="src:annex|src:table" format="A.1 " />
          </xsl:when>
          <xsl:otherwise>
            <xsl:number level="any" count="src:table" />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="self::src:li">
        <xsl:variable name="level" select="count(ancestor::src:ol) mod 3" />
        <xsl:variable name="format">
          <xsl:choose>
            <xsl:when test="$level=1">
              <xsl:text>a) </xsl:text>
            </xsl:when>
            <xsl:when test="$level=2">
              <xsl:text>1) </xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>i) </xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:number format="{$format}" />
      </xsl:when>
      <xsl:when test="ancestor::src:clause">
        <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" format="1.1 " />
      </xsl:when>
      <xsl:when test="self::src:referenced-document">
        <xsl:value-of select="src:abbrev" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:number level="multiple" count="src:annex" format="A.1 " />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="src:firstterm">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="src:strong">
    <fo:block font-weight="bolder">
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:artwork">
    <fo:inline>
      <fo:external-graphic src="{unparsed-entity-uri(@entity)}" height="{@height}" width="{@width}"/>
    </fo:inline> 
  </xsl:template>

  <xsl:template match="src:d-block">
    <fo:block use-attribute-sets="p">
      <xsl:apply-templates />
      <xsl:if test="@type = 'formula'">
        <xsl:choose>
          <xsl:when test="ancestor::src:annex">
            <xsl:number level="single" count="src:annex" format="(A." />
            <xsl:number level="any" count="src:d-block[@type = 'formula']" format="1)" from="src:annex" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:number level="any" count="src:d-block[@type = 'formula']" format="(1)" />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:if>
    </fo:block>
  </xsl:template>
  
  <xsl:template match="src:footnote">
    <fo:footnote>
      <fo:inline font-size="60%" vertical-align="super">
        <xsl:number level="any" count="src:footnote" format="1)"/>
      </fo:inline>
      <fo:footnote-body>
        <fo:list-block provisional-distance-between-starts="{$halfquote}"
          provisional-label-separation="5pt">
          <fo:list-item>
            <fo:list-item-label end-indent="label-end()">
              <fo:block  font-size="80%">
                <xsl:number level="any" count="src:footnote" format="1)"/>
              </fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()">
              <fo:block  font-size="80%">
                <xsl:apply-templates/>
              </fo:block>
            </fo:list-item-body>
          </fo:list-item>
        </fo:list-block>
      </fo:footnote-body>
    </fo:footnote>
  </xsl:template>

  <xsl:template match="src:table">
    <fo:block xsl:use-attribute-sets="float" text-align="center">
      <xsl:apply-templates select="src:title" />
      <xsl:apply-templates select="*[not(self::src:title)]" />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:table/src:title">
    <xsl:variable name="ref">
      <xsl:choose>
        <xsl:when test="ancestor::src:annex">
          <xsl:number level="multiple" count="src:annex|src:table" format="A.1 " />
        </xsl:when>
        <xsl:otherwise>
          <xsl:number level="any" count="src:table" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:call-template name="tabstr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
    </xsl:variable>
    <fo:block text-align="center" font-weight="bold" id="tab{$ref}">
      <xsl:value-of select="concat($text, ' ', $ref)" />
      <xsl:text> &#8211; </xsl:text>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:figure">
    <fo:block xsl:use-attribute-sets="float" text-align="center">
      <xsl:apply-templates select="*[not(self::src:title)]" />
      <xsl:apply-templates select="src:title" />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:figure/src:title">
    <xsl:variable name="ref">
      <xsl:choose>
        <xsl:when test="ancestor::src:annex">
          <xsl:number level="multiple" count="src:annex|src:figure" format="A.1 " />
        </xsl:when>
        <xsl:otherwise>
          <xsl:number level="any" count="src:figure" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <fo:block text-align="center" font-weight="bold" id="fig{$ref}">
      <xsl:text>Figure </xsl:text>
      <xsl:value-of select="$ref" />
      <xsl:text> &#8211; </xsl:text>
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="src:tabular">
    <fo:table space-before=".5em" space-after=".5em" table-layout="fixed" text-align="start">
      <xsl:if test="@frame='all'">
        <xsl:attribute name="border-style">solid</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="src:tgroup"/>
    </fo:table>
  </xsl:template>

  <xsl:template match="src:tgroup">
    <xsl:apply-templates select="src:colspec"/>
    <xsl:apply-templates select="src:thead"/>
    <xsl:apply-templates select="src:tbody"/>
    <xsl:apply-templates select="src:tfoot"/>
    <xsl:apply-templates select=".//src:tabnote" mode="note"/>
  </xsl:template>

  <xsl:template match="src:colspec">
    <xsl:variable name="p" select="substring-before(@colwidth, '*')"/>
    <fo:table-column>
      <xsl:attribute name="column-width">
        <xsl:value-of select="5.1 * $p"/>
        <xsl:text>pt</xsl:text>
      </xsl:attribute>
    </fo:table-column>
  </xsl:template>

  <xsl:template match="src:thead">
    <fo:table-header>
      <xsl:apply-templates/>
    </fo:table-header>
  </xsl:template>

  <xsl:template match="src:tbody">
    <fo:table-body>
      <xsl:apply-templates/>
    </fo:table-body>
  </xsl:template>

  <xsl:template match="src:tfoot">
    <fo:table-footer>
      <xsl:apply-templates/>
    </fo:table-footer>
  </xsl:template>

  <xsl:template match="src:row">
    <fo:table-row keep-with-next="always">
      <xsl:apply-templates/>
    </fo:table-row>
  </xsl:template>

  <xsl:template match="src:entry">
    <xsl:choose>
      <xsl:when test="ancestor::src:thead">
        <xsl:call-template name="ent">
          <xsl:with-param name="tag">th</xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="ent">
          <xsl:with-param name="tag">td</xsl:with-param>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="ent">
    <xsl:param name="tag"/>
    <fo:table-cell padding="0.2em">
      <xsl:variable name="va" select="ancestor-or-self::src:*[@valign][position()=1]/@valign"/>
      <xsl:choose>
        <xsl:when test="$va='top'">
          <xsl:attribute name="display-align">before</xsl:attribute>
        </xsl:when>
        <xsl:when test="$va='bottom'">
          <xsl:attribute name="display-align">after</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="display-align">center</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:if test="@align">
        <xsl:attribute name="text-align">
          <xsl:value-of select="@align"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:if test="@morerows">
        <xsl:attribute name="number-rows-spanned">
          <xsl:value-of select="@morerows + 1"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:if test="@namest and @nameend">
        <xsl:call-template name="colspan">
          <xsl:with-param name="namest" select="@namest"/>
          <xsl:with-param name="nameend" select="@nameend"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="ancestor-or-self::src:*[@colsep][position()=1]/@colsep='1'">
        <xsl:attribute name="border-right-style">solid</xsl:attribute>
      </xsl:if>
      <xsl:if test="ancestor-or-self::src:*[@rowsep][position()=1]/@rowsep='1'">
        <xsl:attribute name="border-bottom-style">solid</xsl:attribute>
      </xsl:if>
      <xsl:choose>
        <xsl:when test="$tag='th'">
          <fo:block text-align="center" font-weight="bold">
            <xsl:apply-templates/>
          </fo:block>
        </xsl:when>
        <xsl:otherwise>
          <fo:block>
            <xsl:apply-templates/>
          </fo:block>
        </xsl:otherwise>
      </xsl:choose>
    </fo:table-cell>
  </xsl:template>

  <xsl:template name="colspan">
    <xsl:param name="namest"/>
    <xsl:param name="nameend"/>
    <xsl:call-template name="colspan-sub">
      <xsl:with-param name="numst">
        <xsl:choose>
          <xsl:when test="parent::src:row/preceding-sibling::src:colspec[@colname=$namest]">
            <xsl:value-of
              select="count(parent::src:row/preceding-sibling::src:colspec[@colname=$namest]/preceding-sibling::src:colspec)"
            />
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of
              select="count(ancestor::src:tgroup/child::src:colspec[@colname=$namest]/preceding-sibling::src:colspec)"
            />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
      <xsl:with-param name="numend">
        <xsl:choose>
          <xsl:when test="parent::src:row/preceding-sibling::src:colspec[@colname=$nameend]">
            <xsl:value-of
              select="count(parent::src:row/preceding-sibling::src:colspec[@colname=$nameend]/preceding-sibling::src:colspec)"
            />
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of
              select="count(ancestor::src:tgroup/child::src:colspec[@colname=$nameend]/preceding-sibling::src:colspec)"
            />
          </xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="colspan-sub">
    <xsl:param name="numst"/>
    <xsl:param name="numend"/>
    <xsl:attribute name="number-columns-spanned">
      <xsl:value-of select="$numend - $numst + 1"/>
    </xsl:attribute>
  </xsl:template>

  <xsl:template match="src:tabnote">
    <fo:block font-size="90%">
      <xsl:call-template name="xref-one"/>
      <xsl:apply-templates/>
    </fo:block>
  </xsl:template>

  <xsl:template match="src:tabnote" mode="note">
    <xsl:text>NOTE </xsl:text>
    <xsl:choose>
      <xsl:when test="@number='nonum'"/>
      <xsl:otherwise>
        <xsl:if test="count(ancestor::src:table//src:tabnote) &gt; 1">
          <xsl:number level="any" count="tabnote" from="table" format="1 "/>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates/>
  </xsl:template>

</xsl:stylesheet>
